# -*- coding: utf-8 -*-
""" Exbetapi main __init__
"""
from .api import ExbetAPI

__version__ = "2.1.0"
__all__ = ["api", "exceptions", "cli"]
